@@ -395,7 +395,7 @@ BitstreamReadHeaders(Bitstream * bs,
 	int32_t time_increment = 0;
 	int resize = 0;
 
-	do {
+	while ((BitstreamPos(bs) >> 3) + 4 <= bs->length) {
 
 		BitstreamByteAlign(bs);
 		start_code = BitstreamShowBits(bs, 32);
@@ -1037,7 +1037,6 @@ BitstreamReadHeaders(Bitstream * bs,
 			BitstreamSkip(bs, 8);
 		}
 	}
-	while ((BitstreamPos(bs) >> 3) < bs->length);
 
 #if 0
 	DPRINTF("*** WARNING: no vop_start_code found");
